==> pano_rtc-0.9.3-dev.3.tar.gz: android/src/main/kotlin/video/pano/pano_rtc/RtcAnnotation.kt <==
package video.pano.pano_rtc

import com.pano.rtc.api.PanoAnnotation
import com.pano.rtc.api.RtcWbView
import video.pano.pano_rtc.api.IRtcAnnotation
import video.pano.pano_rtc.events.RtcAnnotationEvent
import video.pano.pano_rtc.utils.EnumValueConvert.StaticParams.getWBFontStyle
import video.pano.pano_rtc.utils.EnumValueConvert.StaticParams.getWBRoleType
import video.pano.pano_rtc.utils.EnumValueConvert.StaticParams.getWBToolType

class RtcAnnotation(private val annotation: PanoAnnotation?, channelId: String) : FlutterWrapper(),
        IRtcAnnotation {

    init {
        methodChannel = PanoRtcPlugin.createMethodChannel("pano_rtc/api_$channelId")
        eventChannel = PanoRtcPlugin.createEventChannel("pano_rtc/events_$channelId")
        methodChannel.setMethodCallHandler(this)
        eventChannel?.setStreamHandler(this)
        annotation?.setCallback(RtcAnnotationEvent { methodName, data ->
            emit(methodName, data)
        })
    }

    override fun startAnnotation(params: Map<String, *>, callback: Callback) {
        val view = params["view"] as RtcWbView
        callback.success(annotation?.startAnnotation(view))
    }

    override fun stopAnnotation(callback: Callback) {
        callback.success(annotation?.stopAnnotation())
    }

    override fun setVisible(params: Map<String, *>, callback: Callback) {
        val visible = params["visible"] as Boolean
        callback.success(annotation?.setVisible(visible))
    }

    override fun setRoleType(params: Map<String, *>, callback: Callback) {
        val type = params["type"] as Int
        callback.success(annotation?.setRoleType(getWBRoleType(type)))
    }

    override fun setToolType(params: Map<String, *>, callback: Callback) {
        val type = params["type"] as Int
        callback.success(annotation?.setToolType(getWBToolType(type)))
    }

    override fun setLineWidth(params: Map<String, *>, callback: Callback) {
        val size = params["size"] as Int
        callback.success(annotation?.setLineWidth(size))
    }

    override fun setColor(params: Map<String, *>, callback: Callback) {
        val colorMap = params["color"] as Map<*, *>
        val red = (colorMap["red"] as Double).toFloat()
        val green = (colorMap["green"] as Double).toFloat()
        val blue = (colorMap["blue"] as Double).toFloat()
        val alpha = (colorMap["alpha"] as Double).toFloat()
        callback.success(annotation?.setColor(red, green, blue, alpha))
    }

    override fun setFontStyle(params: Map<String, *>, callback: Callback) {
        val style = params["style"] as Int
        callback.success(annotation?.setFontStyle(getWBFontStyle(style)))
    }

    override fun clearContents(params: Map<String, *>, callback: Callback) {
        callback.success(annotation?.clearContents())
    }

    override fun clearUserContents(params: Map<String, *>, callback: Callback) {
        val userId = params["userId"] as Long
        callback.success(annotation?.clearUserContents(userId))
    }

    override fun undo(callback: Callback) {
        callback.success(annotation?.undo())
    }

    override fun redo(callback: Callback) {
        callback.success(annotation?.redo())
    }

    override fun snapshot(params: Map<String, *>, callback: Callback) {
        val outputDir = params["outputDir"] as String
        callback.success(annotation?.snapshot(outputDir))
    }
}

==> pano_rtc-0.9.4-dev.4.tar.gz: android/src/main/kotlin/video/pano/pano_rtc/RtcAnnotation.kt <==
package video.pano.pano_rtc

import com.pano.rtc.api.PanoAnnotation
import com.pano.rtc.api.RtcWbView
import video.pano.pano_rtc.api.IRtcAnnotation
import video.pano.pano_rtc.events.RtcAnnotationEvent
import video.pano.pano_rtc.utils.EnumValueConvert.StaticParams.getWBFontStyle
import video.pano.pano_rtc.utils.EnumValueConvert.StaticParams.getWBRoleType
import video.pano.pano_rtc.utils.EnumValueConvert.StaticParams.getWBToolType

class RtcAnnotation(private val annotation: PanoAnnotation?, channelId: String) : FlutterWrapper(),
        IRtcAnnotation {

    init {
        methodChannel = PanoRtcPlugin.createMethodChannel("pano_rtc/api_$channelId")
        eventChannel = PanoRtcPlugin.createEventChannel("pano_rtc/events_$channelId")
        methodChannel.setMethodCallHandler(this)
        eventChannel?.setStreamHandler(this)
        annotation?.setCallback(RtcAnnotationEvent { methodName, data ->
            emit(methodName, data)
        })
    }

    override fun startAnnotation(params: Map<String, *>, callback: Callback) {
        val view = params["view"] as RtcWbView
        callback.success(annotation?.startAnnotation(view))
    }

    override fun stopAnnotation(callback: Callback) {
        callback.success(annotation?.stopAnnotation())
    }

    override fun setVisible(params: Map<String, *>, callback: Callback) {
        val visible = params["visible"] as Boolean
        callback.success(annotation?.setVisible(visible))
    }

    override fun setRoleType(params: Map<String, *>, callback: Callback) {
        val type = (params["type"] as Number).toInt()
        callback.success(annotation?.setRoleType(getWBRoleType(type)))
    }

    override fun setToolType(params: Map<String, *>, callback: Callback) {
        val type = (params["type"] as Number).toInt()
        callback.success(annotation?.setToolType(getWBToolType(type)))
    }

    override fun setLineWidth(params: Map<String, *>, callback: Callback) {
        val size = (params["size"] as Number).toInt()
        callback.success(annotation?.setLineWidth(size))
    }

    override fun setColor(params: Map<String, *>, callback: Callback) {
        val colorMap = params["color"] as Map<*, *>
        val red = (colorMap["red"] as Number).toFloat()
        val green = (colorMap["green"] as Number).toFloat()
        val blue = (colorMap["blue"] as Number).toFloat()
        val alpha = (colorMap["alpha"] as Number).toFloat()
        callback.success(annotation?.setColor(red, green, blue, alpha))
    }

    override fun setFontStyle(params: Map<String, *>, callback: Callback) {
        val style = (params["style"] as Number).toInt()
        callback.success(annotation?.setFontStyle(getWBFontStyle(style)))
    }

    override fun clearContents(params: Map<String, *>, callback: Callback) {
        callback.success(annotation?.clearContents())
    }

    override fun clearUserContents(params: Map<String, *>, callback: Callback) {
        val userId = (params["userId"] as Number).toLong()
        callback.success(annotation?.clearUserContents(userId))
    }

    override fun undo(callback: Callback) {
        callback.success(annotation?.undo())
    }

    override fun redo(callback: Callback) {
        callback.success(annotation?.redo())
    }

    override fun snapshot(params: Map<String, *>, callback: Callback) {
        val outputDir = params["outputDir"] as String
        callback.success(annotation?.snapshot(outputDir))
    }
}
